/**
 * DevExtreme (core/element_data.js)
 * Version: 17.2.0 (build 17273)
 * Build date: Sat Sep 30 2017
 *
 * Copyright (c) 2012 - 2017 Developer Express Inc. ALL RIGHTS RESERVED
 * Read about DevExtreme licensing here: https://js.devexpress.com/Licensing/
 */
"use strict";
var WeakMap = require("./polyfills/weak_map");
var dataMap = new WeakMap;
var strategy = {
    data: function(element, key, value) {
        if (!element) {
            return
        }
        var elementData = dataMap.get(element);
        if (!elementData) {
            elementData = {};
            dataMap.set(element, elementData)
        }
        if (void 0 === key) {
            return elementData
        }
        if (2 === arguments.length) {
            return elementData[key]
        }
        elementData[key] = value;
        return value
    },
    removeData: function(element, key) {
        if (!element) {
            return
        }
        if (void 0 === key) {
            dataMap.delete(element)
        } else {
            var elementData = dataMap.get(element);
            if (elementData) {
                delete elementData[key]
            }
        }
    },
    cleanData: function(elements) {
        for (var i = 0; i < elements.length; i++) {
            dataMap.delete(elements[i])
        }
    }
};
exports.setDataStrategy = function(value) {
    strategy = value
};
exports.getDataStrategy = function() {
    return strategy
};
exports.data = function() {
    return strategy.data.apply(this, arguments)
};
exports.cleanData = function() {
    return strategy.cleanData.apply(this, arguments)
};
exports.removeData = function() {
    return strategy.removeData.apply(this, arguments)
};
exports.cleanDataRecursive = function(element, cleanSelf) {
    if (!(element instanceof Element)) {
        return
    }
    var childElements = element.getElementsByTagName("*");
    strategy.cleanData(childElements);
    if (cleanSelf) {
        strategy.cleanData([element])
    }
};
